# Traefik Ingress 部署

此项目用于介绍如何在`Kubernets`环境中部署 Traefik。


## 部署架构介绍

![部署架构图](images/arch.png)

`Traefik`使用`DaemonSet`方式部署在K8s集群中，监听`80`端口，`80`端口采用`hostPort`方式与节点网络绑定。`Traefik`作为K8s集群接入外部流量的统一入口。

为方便管理，将`Traefik`部署到专有的节点，通过给节点打上`IngressProxy=true`标签，使用`nodeSelector`将`Traefik Pod`调度到指定节点。如上图，在`Node01`上打有`IngressProxy=true`标签，则`Traefik Pod`只会在`Node01`上启动。生产环境建议部署到两台节点上（给两台节点打标签）。

本架构中使用`CLB`进行反向代理与`SSL`证书的配置，当`https`流量到达`CLB`后，会进行`SSL`证书加密卸载，然后使用`http`请求到`Traefik Pod`，`Traefik Pod`会根据请求主机和路径等信息将请求正确路由到后端服务`Pod`。

## 文件介绍

```
.
├── README.md         # 本文档
├── images            # 图片文件夹
│   └── arch.png
├── traefik-config.yaml           # Traefik 配置文件 yaml
├── traefik-crd-2.5.2.yaml        # Traefik CRD yaml
├── traefik-dashboard-route.yaml  # Traefik Dashboard 路由配置 yaml
├── traefik-deploy.yaml           # Traefik DaemonSet 部署 yaml
└── traefik-rbac.yaml             # Traefik RBAC 配置 yaml
```

`traefik-dashboard-route.yaml`文件中的`Host`需要修改自己所需域名，可以通过此域名访问到`Traefik`到`Dashboard`方便查看路由信息。


## 部署操作

使用如下命令进行部署。

```
# 给节点打标签
kubectl label nodes Node01 IngressProxy=true

# 部署 Traefik
kubectl -n kube-system apply -f traefik-config.yaml -f traefik-crd-2.5.2.yaml -f traefik-dashboard-route.yaml -f traefik-rbac.yaml -f traefik-deploy.yaml 
```


查看部署结果：

```
$ kubectl -n kube-system get pods -l app=traefik
NAME                               READY   STATUS    RESTARTS   AGE
traefik-ingress-controller-mz6jv   1/1     Running   0          1m
```

## 配置 CLB

以阿里云`CLB`为例，首先创建一个`https`的监听，端口配置为`443`，配置自己所需的证书，后端服务器选择`Node01`，后端服务器端口选择`80`，配置完成类似如下图：
![https监听](images/clb-https.png)

配置 `http` `80` 端口监听，将其重定向到`https`监听，配置完成如下图：
![http监听](images/clb-http.png)


## 验证

如上步骤完成后，访问`Traefik Dashboard`地址，能够正常查看到路由信息，代表配置完成。

![Traefik Dashboard](images/traefik-dashboard.png)

（完）